==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.backup.osgi/src/com/openexchange/office/backup/osgi/BackupOfficeActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.backup.osgi;

import java.util.List;

import org.slf4j.Logger;

import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
import com.openexchange.filemanagement.DistributedFileManagement;
import com.openexchange.filemanagement.ManagedFileManagement;
import com.openexchange.office.backup.distributed.DistributedManagedFileLocker;
import com.openexchange.office.backup.manager.DocumentBackupController;
import com.openexchange.office.backup.manager.impl.DocumentBackupManager;
import com.openexchange.office.hazelcast.doc.DocumentDirectory;
import com.openexchange.office.hazelcast.doc.DocumentResourcesDirectory;
import com.openexchange.office.tools.logging.LogFactory;
import com.openexchange.office.tools.osgi.ActivatorBase;

//=============================================================================
public class BackupOfficeActivator extends ActivatorBase
{
	//-------------------------------------------------------------------------   
    private static final String SERVICE_NAME = "com.openexchange.office.backup";

    //-------------------------------------------------------------------------   
    private static final Logger LOG = LogFactory.getSlfLog(BackupOfficeActivator.class);

    //-------------------------------------------------------------------------   
    public BackupOfficeActivator ()
        throws Exception
    {
    	super (SERVICE_NAME);
    }
    
    //-------------------------------------------------------------------------   
    @Override
    protected void listMandatoryServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
        lServices.add(ManagedFileManagement     .class);
        lServices.add(DistributedFileManagement .class);
        lServices.add(DocumentDirectory         .class);
        lServices.add(DocumentResourcesDirectory.class);
        lServices.add(IDBasedFolderAccessFactory.class);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listOptionalServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	// no optional services
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void activate()
    	throws Exception
    {
	    // Retrieve the needed class to access the hazelcast data
	    final DocumentDirectory          aDocStateDir = getService(DocumentDirectory         .class);
	    final DocumentResourcesDirectory aDocResDir   = getService(DocumentResourcesDirectory.class);
	
	    // create the one and only distributed backup instance for this node
	    DistributedManagedFileLocker.init(null);
	    DocumentBackupManager       .init(null, aDocStateDir, aDocResDir);
	
	    registerService(DocumentBackupController.class, DocumentBackupManager.get());
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void deactivate()
    	throws Exception
    {
    	DocumentBackupManager.destroy();
    }
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.backup.osgi/src/com/openexchange/office/backup/osgi/BackupOfficeActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.backup.osgi;

import java.util.List;

import org.slf4j.Logger;

import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
import com.openexchange.filemanagement.DistributedFileManagement;
import com.openexchange.filemanagement.ManagedFileManagement;
import com.openexchange.office.backup.distributed.DistributedManagedFileLocker;
import com.openexchange.office.backup.manager.DocumentBackupController;
import com.openexchange.office.backup.manager.impl.DocumentBackupManager;
import com.openexchange.office.hazelcast.doc.DocumentDirectory;
import com.openexchange.office.hazelcast.doc.DocumentResourcesDirectory;
import com.openexchange.office.imagemgr.IResourceManagerFactory;
import com.openexchange.office.tools.logging.LogFactory;
import com.openexchange.office.tools.osgi.ActivatorBase;

//=============================================================================
public class BackupOfficeActivator extends ActivatorBase
{
	//-------------------------------------------------------------------------   
    private static final String SERVICE_NAME = "com.openexchange.office.backup";

    //-------------------------------------------------------------------------   
    private static final Logger LOG = LogFactory.getSlfLog(BackupOfficeActivator.class);

    //-------------------------------------------------------------------------   
    public BackupOfficeActivator ()
        throws Exception
    {
    	super (SERVICE_NAME);
    }
    
    //-------------------------------------------------------------------------   
    @Override
    protected void listMandatoryServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
        lServices.add(ManagedFileManagement     .class);
        lServices.add(DistributedFileManagement .class);
        lServices.add(DocumentDirectory         .class);
        lServices.add(DocumentResourcesDirectory.class);
        lServices.add(IDBasedFolderAccessFactory.class);
        lServices.add(IResourceManagerFactory   .class);
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void listOptionalServiceImports(final List< Class< ? >> lServices)
    	throws Exception
    {
    	// no optional services
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void activate()
    	throws Exception
    {
	    // Retrieve the needed class to access the hazelcast data
	    final DocumentDirectory          aDocStateDir = getService(DocumentDirectory         .class);
	    final DocumentResourcesDirectory aDocResDir   = getService(DocumentResourcesDirectory.class);
	
	    // create the one and only distributed backup instance for this node
	    DistributedManagedFileLocker.init(null);
	    DocumentBackupManager       .init(null, aDocStateDir, aDocResDir);
	
	    registerService(DocumentBackupController.class, DocumentBackupManager.get());
    }

    //-------------------------------------------------------------------------   
    @Override
    protected void deactivate()
    	throws Exception
    {
    	DocumentBackupManager.destroy();
    }
}
